@@ -1,5 +1,7 @@
 #!/usr/bin/env python
 import json
+import os
+import pickle
 import platform
 import requests
 import sys
@@ -7,28 +9,81 @@ import time
 from datetime import datetime
 from functools import wraps
 from pkg_resources import parse_version as V
+from tempfile import gettempdir
 
-__version__ = '0.4'
+__version__ = '0.5'
 
 
 def cache_results(function):
+    def save_to_permacache():
+        """Save the in-memory cache data to the permacache.
+
+        There is a race condition here between two processes updating at the
+        same time. It's perfectly acceptable to lose and/or corrupt the
+        permacache information as each process's in-memory cache will remain
+        in-tact.
+
+        """
+        update_from_permacache()
+        with open(filename, 'wb') as fp:
+            pickle.dump(cache, fp, pickle.HIGHEST_PROTOCOL)
+
+    def update_from_permacache():
+        """Attempt to update newer items from the permacache."""
+        try:
+            permacache = pickle.load(open(filename, 'rb'))
+        except Exception:
+            return
+        for key, value in permacache.items():
+            if key not in cache or value[0] > cache[key][0]:
+                cache[key] = value
+
     cache = {}
     cache_expire_time = 3600
+    filename = os.path.join(gettempdir(), 'update_checker_cache.pkl')
+    update_from_permacache()
 
     @wraps(function)
     def wrapped(obj, package_name, package_version, **extra_data):
         now = time.time()
         key = (package_name, package_version)
-        if key in cache:
+        if key in cache:  # Check the in-memory cache
             cache_time, retval = cache[key]
             if now - cache_time < cache_expire_time:
                 return retval
         retval = function(obj, package_name, package_version, **extra_data)
         cache[key] = now, retval
+        save_to_permacache()
         return retval
     return wrapped
 
 
+# This class must be defined before UpdateChecker in order to unpickle objects
+# of this type
+class UpdateResult(object):
+    """Contains the information for a package that has an update."""
+    def __init__(self, package, running, available, release_date):
+        self.available_version = available
+        self.package_name = package
+        self.running_version = running
+        if release_date:
+            self.release_date = datetime.strptime(release_date,
+                                                  '%Y-%m-%dT%H:%M:%S')
+        else:
+            self.release_date = None
+
+    def __str__(self):
+        retval = ('Version {0} of {1} is outdated. Version {2} '
+                  .format(self.running_version, self.package_name,
+                          self.available_version))
+        if self.release_date:
+            retval += 'was released {0}.'.format(
+                pretty_date(self.release_date))
+        else:
+            retval += 'is available.'
+        return retval
+
+
 class UpdateChecker(object):
     """A class to check for package updates."""
     def __init__(self, url=None):
@@ -61,30 +116,6 @@ class UpdateChecker(object):
                             release_date=data['data']['upload_time'])
 
 
-class UpdateResult(object):
-    """Contains the information for a package that has an update."""
-    def __init__(self, package, running, available, release_date):
-        self.available_version = available
-        self.package_name = package
-        self.running_version = running
-        if release_date:
-            self.release_date = datetime.strptime(release_date,
-                                                  '%Y-%m-%dT%H:%M:%S')
-        else:
-            self.release_date = None
-
-    def __str__(self):
-        retval = ('Version {0} of {1} is outdated. Version {2} '
-                  .format(self.running_version, self.package_name,
-                          self.available_version))
-        if self.release_date:
-            retval += 'was released {0}.'.format(
-                pretty_date(self.release_date))
-        else:
-            retval += 'is available.'
-        return retval
-
-
 def pretty_date(the_datetime):
     # Source modified from
     # http://stackoverflow.com/a/5164027/176978
